@@ -150,6 +150,15 @@ def setup(settings_path=None, **settings_patches):
     local('echo "[]" > %s' % app_ports_path())
     local('chmod o+rx %s' % beanstalk_stack_base)
 
+    # Global ini
+    local('mkdir -p /etc/beanstalk')
+    global_uwsgi_ini_path = os.path.join(BEANSTALK_ROOT_PATH, 'static/global_uwsgi.ini')
+    with hide('everything'):
+        uid = local('id -u beanstalk', capture=True)
+    global_uwsgi_ini = render_file(global_uwsgi_ini_path, beanstalk_settings, BEANSTALK_UID=uid)
+    with open('/etc/beanstalk/uwsgi.ini', 'w') as f:
+        f.write(global_uwsgi_ini)
+
     # Apache command
     print section_title('Create apache-reload command')
     httpd_cmd_path = '/usr/sbin/httpd_reload'
